/**
 * Clone a object
 * @function clone
 * @param {Object} src - Source object to clone
 * @param {Object} [options={}] - Optional settings
 * @returns {Object} - Cloned object
 */
'use strict';

/** @lends clone */

function clone(src) {
  var options = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];

  var cloned = Object.assign({}, src);

  var without = [].concat(options.without || []);
  var _iteratorNormalCompletion = true;
  var _didIteratorError = false;
  var _iteratorError = undefined;

  try {
    for (var _iterator = without[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
      var name = _step.value;

      delete cloned[name];
    }
  } catch (err) {
    _didIteratorError = true;
    _iteratorError = err;
  } finally {
    try {
      if (!_iteratorNormalCompletion && _iterator.return) {
        _iterator.return();
      }
    } finally {
      if (_didIteratorError) {
        throw _iteratorError;
      }
    }
  }

  return cloned;
}

module.exports = clone;
//# sourceMappingURL=data:application/json;base64,bnVsbA==